Skip to contents

List all validation configuration files that are delivered with the package and can be directly imported with “getConfig()“ or used in “validateScenarios()“ and “validationReport()“.

Usage

listConfigs()

Value

character vector of config names