List all validation report templates (.Rmd) that are delivered with the package and can be used as “report“ in “validationReport()“.
List all validation report templates (.Rmd) that are delivered with the package and can be used as “report“ in “validationReport()“.